import QtQuick
import QtQuick.Controls

import Artix.Gui

/**
 * @brief Поле ввода текста
 * @param hideCursor скрывать курсор при вводе текста
 * @param fixedCursorPosition зафиксировать курсор в конце поля ввода
 */
TextField {
    id: root
    Style.type: "textField"
    Style.class: "default"

    property bool hideCursor: false
    property bool fixedCursorPosition: false
    property bool down: tapHandler.pressed
    property alias pressed: tapHandler.pressed
    signal clicked()

    padding: 0
    font: Style.text.font
    color: Style.text.color
    // cursorVisible принимает значение true при получении фокуса
    onCursorVisibleChanged: if (hideCursor && cursorVisible) cursorVisible = false
    onCursorPositionChanged: if (fixedCursorPosition) cursorPosition = text.length

    background: Rectangle {
        color: root.Style.background.color
        border.color: root.Style.background.border.color
        border.width: root.Style.background.border.width
        radius: root.Style.background.radius

        Behavior on color { ColorAnimation { duration: 100 }}
    }

    TapHandler {
        id: tapHandler
        onTapped: {
            root.focus = true
            root.clicked()
        }
    }
}
