import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог выбора из двух вариантов
 */
ModalView {
    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: handler.sendAnswer(true)
        onCancel: handler.sendAnswer(false)
    }

    contentItem: ColumnLayout {
        spacing: 0
        Image {
            id: image
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredHeight: 72
            source: Style.parameter(params.image)
        }

        Item { Layout.preferredHeight: 16; visible: image.visible }
        BasicLabel {
            id: message
            Layout.fillWidth: true
            Style.class: "choiceBoxMessage"
            horizontalAlignment: Text.AlignHCenter
            Tr { tr: params.message }
        }

        Item { Layout.preferredHeight: 16; visible: note.visible }
        BasicLabel {
            id: note
            Layout.fillWidth: true
            Style.class: "choiceBoxNote"
            horizontalAlignment: Text.AlignHCenter
            visible: text.length > 0
            Tr { tr: params.note }
        }

        Item { Layout.preferredHeight: 32 }
        RowLayout {
            BasicButton {
                Layout.preferredWidth: 200
                Layout.preferredHeight: 68
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Style.class: "choiceBoxYes"
                Tr { tr: params.yesButton }
                onClicked: handler.sendAnswer(true)
            }
            Item { Layout.fillWidth: true }
            BasicButton {
                Layout.preferredWidth: 200
                Layout.preferredHeight: 68
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Style.class: "choiceBoxNo"
                Tr { tr: params.noButton }
                onClicked: handler.sendAnswer(false)
            }
        }
    }

    DialogHandler { id: handler }
}
