import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import Qt.labs.qmlmodels

import "../components"
import "./view"

import Artix.Handlers
import Artix.Core
import Artix.Models

/**
 * @brief Диалог выбора документа
 */
ChoiceTable {
    id: root

    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: selectCurrentIndex()
        onCancel: reject()
    }

    model: FilterProxyModel {
        id: filterModel
        sourceModel: DocumentChoiceModel {
            id: documentChoiceModel
            onModelReset: updateDiscardedRows()
            onTopChanged: update(root.filter)
        }
    }
    titleTr: Utils.makeTr("documentChoiceTitle", "Выберите чек")
    okButtonTr: Utils.makeTr("documentChoiceFormOkButton", "Выбрать")
    cancelButtonTr: Utils.makeTr("documentChoiceFormCancelButton", "Назад")
    inputPlaceholderTr: Utils.makeTr("documentChoiceFormInputDataLineEditText", "Номер документа")
    columnsOrder: [
        "checknum",
        "frdocnum",
        "time_end",
        "valut",
        "sumb",
    ]
    columnsHorizontalAlignment: [
        Qt.AlignLeft,   // Номер документа
        Qt.AlignLeft,   // Номер документа из ФР
        Qt.AlignLeft,   // Время закрытия
        Qt.AlignLeft,   // Тип оплаты
        Qt.AlignRight,  // Сумма
    ]
    columnsWidth: [
        60,     // Номер документа
        60,     // Номер документа из ФР
        150,    // Время закрытия
        tableAvailableWidth - 470,  // Тип оплаты
        200,    // Сумма
    ]

    onFilterChanged: documentChoiceModel.update(root.filter)

    // Обработчик
    DialogHandler { id: handler }

    onAccept: (index) => {
        var sourceIndex = filterModel.mapToSource(filterModel.index(index.row, 6))
        handler.sendAnswer(documentChoiceModel.getDocumentId(sourceIndex.row))
    }
    onReject: handler.sendAnswer(-1)

    function updateDiscardedRows() {
        if (!params.discardedStatuses)
            return

        if (params.discardedStatuses.includes(DocumentStatus.HasReturns))
            filterModel.setDiscardedRows(documentChoiceModel.getDiscardedRowsVariant(true))
        else if (params.discardedStatuses.includes(DocumentStatus.Returned))
            filterModel.setDiscardedRows(documentChoiceModel.getDiscardedRowsVariant(false))
    }

    Component.onCompleted: {
        documentChoiceModel.prepare(params.choiceType, params.shiftId, params.types, params.statuses)
        updateDiscardedRows()
    }
}
