import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "./view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Диалог ввода количества
 */
ModalView {
    id: root
    implicitWidth: keyboard.visible ? 464 + 256 : 464
    padding: 24

    property BasicTextField eventReceiver: inputField
    property DialogEventFilter eventFilter: DialogEventFilter {
        id: eventFilter
        onKeyboardData: (data, rawData, source) => {
               inputField.text = ""
               handler.input(data, rawData, source)
        }
        onOk: {
            if (!inputField.acceptableInput)
                return
            inputField.value = inputField.text
            handler.sendAnswer(inputField.value, InputSource.Ui)
        }
        onCancel: handler.sendAnswer()
    }

    property bool fractional: params.fractional
    Component.onCompleted: {
        if (fractional) {
            inputField.forceActiveFocus()
            inputField.selectAll()
        }
    }

    contentItem: ColumnLayout {
        spacing: 24
        Layout.fillWidth: true

        RowLayout {
            ColumnLayout {
                BasicLabel {
                    id: message
                    Style.class: "inputQuantityMessage"
                    Layout.fillWidth: true
                    horizontalAlignment: Label.AlignHCenter
                    Tr { tr: params.message }
                    visible: !posInfo.visible
                }
                RowLayout {
                    id: posInfo
                    visible: params.name.length > 0
                    spacing: 24
                    Image {
                        id: posImage
                        Layout.preferredWidth: 164
                        Layout.preferredHeight: 164
                        fillMode: Image.PreserveAspectFit
                        source: params.image.length > 0 ? params.image : Style.parameter("icon.goodsPlaceholder")

                    }
                    ColumnLayout {
                        spacing: 24
                        BasicLabel {
                            Style.class: "inputQuantityName"
                            Layout.fillWidth: true
                            Layout.fillHeight: true
                            text: params.name
                        }
                        BasicLabel {
                            id: posPrice
                            Style.class: "inputQuantityPrice"
                            Layout.fillWidth: true
                            text: Utils.formatMoneyItem(params.price)
                        }
                    }
                }
                RowLayout {
                    id: quantityControls
                    Layout.alignment: Qt.AlignHCenter
                    spacing: 24
                    BasicButton {
                        visible: !keyboard.visible
                        Layout.preferredWidth: 72
                        Layout.preferredHeight: 72
                        Style.class: "inputQuantityChange"
                        icon: Style.parameter("icon.minus")
                        onClicked: inputField.value -= 1
                        enabled: inputField.value >= 1
                    }
                    BasicTextField {
                        id: inputField
                        Style.class: "inputQuantityTextField"
                        inputMethodHints: Qt.ImhDigitsOnly
                        echoMode: TextInput.Normal
                        Layout.preferredWidth: root.fractional ? 320 : 160
                        Layout.preferredHeight: 72
                        horizontalAlignment: Text.AlignHCenter
                        hideCursor: true
                        fixedCursorPosition: true
                        enabled: root.fractional
                        validator: root.fractional ? dv : iv
                        DoubleValidator {
                            id: dv
                            notation: DoubleValidator.StandardNotation
                            bottom: 0.0
                            decimals: 3
                        }
                        IntValidator { id: iv; bottom: 0 }

                        property real value: params.defaultValue
                        text: root.fractional ? Utils.weightStr(value) : value.toFixed(0)
                    }
                    BasicButton {
                        visible: !keyboard.visible
                        Layout.preferredWidth: 72
                        Layout.preferredHeight: 72
                        Style.class: "inputQuantityChange"
                        icon: Style.parameter("icon.plus")
                        onClicked: inputField.value += 1
                    }
                }
            }
            InlineKeyboard {
                id: keyboard
                visible: root.fractional
                Layout.preferredHeight: 296
                Layout.alignment: Qt.AlignHCenter
                width: 256
                layoutType: "digits"
            }
        }

        RowLayout {
            Layout.alignment: Qt.AlignHCenter
            spacing: 24
            BasicButton {
                Style.class: "inputQuantityOk"
                Layout.preferredWidth: 196
                Layout.preferredHeight: 72
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Tr { tr: params.okButtonText }
                onClicked: {
                    if (!inputField.acceptableInput)
                        return
                    inputField.value = inputField.text
                    handler.sendAnswer(inputField.value, InputSource.Ui)
                }
            }
            BasicButton {
                Style.class: "inputQuantityCancel"
                Layout.preferredWidth: 196
                Layout.preferredHeight: 72
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Tr { tr: params.cancelButtonText }
                onClicked: handler.sendAnswer()
            }
        }
    }

    DialogHandler { id: handler }
}
