import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "view"

import Artix.Handlers
import Artix.Models
import Artix.Core
import Artix.Gui

/**
 * @brief Форма плиточного меню. Значение currentMenu равное 1 соответствует главному меню ПО
 */
BasicView {
    id: root
    padding: 24
    topPadding: 0
    bottomPadding: 38

    property var menuStack: []  // стек меню
    property int currentMenu: 1 // текущее меню
    property string lastSelectedName
    property var titleStack: [ Utils.makeTr("menuTitleMain", "Главная") ]

    component DrawerSum: GroupBox {
        Style.class: "menuCashDrawer"
        interactive: false
        ColumnLayout {
            anchors { left: parent.left; leftMargin: 64; verticalCenter: parent.verticalCenter }
            spacing: 4
            BasicLabel {
                Style.class: "menuCashDrawerLabel"
                Tr { code: "menuCashDrawerLabel"; defaultMessage: "Сумма в денежном ящике" }
            }
            BasicLabel {
                Style.class: "menuCashDrawerSum"
                text: Utils.formatMoneyItem(SystemInfo.cashDrawerSum())
            }
        }
    }

    header: Item {
        TopPanel { anchors.fill: parent; anchors.leftMargin: 24 }
        height: 72
    }
    contentItem: ColumnLayout {
        spacing: 0
        BasicLabel {
            Style.class: "menuTitle"
            Tr { id: titleTr; code: "menuTitleMain"; defaultMessage: "Главная" }
        }
        Item { Layout.preferredHeight: 16 }
        DrawerSum {
            id: drawerSum
            Layout.fillWidth: true
            Layout.preferredHeight: 167.34
            visible: menu.hasMoneyOperation && Config.getLogical("Misc:showCashDrawerSum", true)
        }
        Item { Layout.preferredHeight: 20; visible: drawerSum.visible }
        SwipeMenu {
            id: menu
            Layout.fillWidth: true
            Layout.fillHeight: true

            property bool hasMoneyOperation: false // в меню есть COMMAND_MONEYIN или COMMAND_MONEYOUT

            model: MenuModel {
                onLayoutAboutToBeChanged: menu.hasMoneyOperation = false
                Component.onCompleted: refresh(currentMenu, true)
            }
            rows: drawerSum.visible ? 2 : 3
            delegate: BasicButton {
                required property int index
                required property string style
                required property int actionCode
                required property string actionName
                required property string icon
                Style.class: style
                x: menu.cellX(index)
                y: menu.cellY(index)
                width: menu.cellWidth
                height: menu.cellHeight
                padding: 24
                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                iconLayout {
                    preferredWidth: 64
                    preferredHeight: 64
                    alignment: Qt.AlignRight | Qt.AlignBottom
                }
                text: actionName
                icon: icon
                onClicked: {
                    lastSelectedName = actionName
                    handler.itemSelected(actionCode)
                }
                Component.onCompleted: {
                    if (handler.checkForMoneyOperation(actionCode))
                        menu.hasMoneyOperation = true
                }
            }
        }
    }
    footer: BottomPanel {}

    MenuHandler {
        id: handler
        mainMenu: true
        onGoToMenu: (menuCode) => {
                        menuStack.push({ menuCode: currentMenu, pageIndex: menu.pageIndex })
                        menu.model.refresh(menuCode, true)
                        menu.setCurrentPage(0)
                        currentMenu = menuCode
                        titleStack.push(Utils.makeTr("undefined", lastSelectedName))
                        titleTr.tr = titleStack[titleStack.length - 1]
                    }
        onMenuExit: () => {
                        var menuItem = menuStack.pop()
                        menu.model.refresh(menuItem.menuCode, true)
                        menu.setCurrentPage(menuItem.pageIndex)
                        currentMenu = menuItem.menuCode
                        titleStack.pop()
                        titleTr.tr = titleStack[titleStack.length - 1]
                    }
    }
}
