import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Окно сообщения
 */
ModalView {
    id: dialog

    property int messageType: params.type
    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: handler.sendAnswer()
        onCancel: handler.sendAnswer()
    }

    ColumnLayout {
        width: parent.width
        spacing: 0
        Image {
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredHeight: 72
            source: {
                if (dialog.messageType === DialogEnum.Error)
                    return Style.parameter("icon.dialog.error")
                if (dialog.messageType === DialogEnum.Warning)
                    return Style.parameter("icon.dialog.warning")
                return Style.parameter("icon.dialog.info")
            }
        }
        Item { height: 24 }
        BasicLabel {
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: parent.width
            horizontalAlignment: Text.AlignHCenter
            Style.class: "messageBoxMessage"
            Tr { tr: params.message }
        }
        Item { height: 32 }
        BasicButton {
            id: okButton
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 200
            Layout.preferredHeight: 68
            textLayout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
            Style.class: "messageBoxOk"
            visible: !params.hideButton
            Tr { code: "okButton"; defaultMessage: "OK" }
            DialogHandler { id: handler }
            onClicked: handler.sendAnswer()
        }
    }
}
