import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог сканирования
 */
ModalView {
    id: root

    property DialogEventFilter eventFilter: DialogEventFilter {
        onKeyboardData: (data, rawData, source) => handler.input(data, rawData, source)
        onOk: if (okButton.visible) accept()
        onCancel: reject()
    }

    contentItem: ColumnLayout {
        spacing: 0
        Image {
            id: image
            Layout.alignment: Qt.AlignHCenter
            fillMode: Image.PreserveAspectFit
            visible: params.image.length > 0
            source: {
                if (params.image.length > 0)
                    return params.image.substring(0, 2) === ":/" ? "qrc" + params.image : Style.parameter(params.image)
                return ""
            }
        }
        Item { Layout.preferredHeight: 16; visible: image.visible }
        BasicLabel {
            id: message
            Layout.fillWidth: true
            Style.class: "choiceBoxMessage"
            horizontalAlignment: Text.AlignHCenter
            Tr { tr: params.message }
        }
        Item { Layout.preferredHeight: 32 }
        RowLayout {
            Layout.alignment: Qt.AlignHCenter
            BasicButton {
                id: okButton
                Layout.preferredWidth: 200
                Layout.preferredHeight: 68
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Style.class: "scanBarcodeOk"
                Tr { tr: params.okButtonText }
                visible: params.withoutMark
                onClicked: root.accept()
            }
            Item { Layout.fillWidth: true; visible: okButton.visible }
            BasicButton {
                Layout.preferredWidth: 200
                Layout.preferredHeight: 68
                textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                Style.class: okButton.visible ? "scanBarcodeCancel" : "scanBarcodeSingleCancel"
                Tr { tr: params.cancelButtonText }
                onClicked: root.reject()
            }
        }
    }

    DialogHandler {
        id: handler
        allowDevices: params.allowedDevices
    }

    function accept() {
        handler.sendAnswer("withoutMark", InputSource.Ui)
    }

    function reject() {
        handler.sendAnswer("", InputSource.Ui)
    }
}
