import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"

import Artix.Models
import Artix.Gui

/**
 * @brief Представление панели действий
 */
Item {
    id: root
    property alias context: actionPanelModel.context    // Идентификатор контекста
    property alias page: actionPanelModel.page          // Номер страницы панели
    signal clicked(int actionCode)                      // Событие о нажатии кнопки
    property var pageStack: []                          // стек страниц панели

    readonly property real rowSpacing: 8     // Отступы между строками
    readonly property real columnSpacing: 8  // Отступы между столбцами
    readonly property int rows: actionPanelModel.rows       // Количество строк
    readonly property int columns: actionPanelModel.columns // Количество столбцов
    readonly property real cellWidth: (width - columnSpacing * (columns - 1)) / columns // Ширина кнопки
    readonly property real cellHeight: (height - rowSpacing * (rows - 1)) / rows        // Высота кнопки

    Repeater {
        model: ActionPanelModel { id: actionPanelModel }
        // Элемент панели
        delegate: BasicButton {
            Style.class: style
            x: column * (root.cellWidth + root.columnSpacing)
            y: row * (root.cellHeight + root.rowSpacing)
            width: root.cellWidth * columnSpan + root.columnSpacing * (columnSpan - 1)
            height: root.cellHeight * rowSpan + root.rowSpacing * (rowSpan - 1)

            textLayout {
                fillWidth: true
                fillHeight: true
            }
            iconLayout {
                alignment: Qt.AlignRight | Qt.AlignTop
                preferredWidth: 32
                preferredHeight: 32
            }
            verticalAlignment: Text.AlignBottom
            text: name
            icon: model.icon
            onClicked: root.clicked(code)
            Component.onCompleted: if (backgroundColor) color = backgroundColor
        }
    }
    // Установить новую страницу с сохранением текущей в стеке
    function pushPage(page) {
        pageStack.push(root.page)
        root.page = page
    }
    // Поднять предыдущую страницу из стека, если она есть
    function popPage() {
        if (pageStack.length > 0)
            page = pageStack.pop()
    }
}
