import QtQuick
import QtQuick.Layouts

import "../../components"

import Artix.Core
import Artix.Gui

/**
 * @brief Нижняя панель
 */
GroupBox {
    height: 32
    interactive: false
    Style.class: "bottomPanel"

    RowLayout {
        anchors.left: parent.left
        anchors.verticalCenter: parent.verticalCenter
        anchors.leftMargin: 16
        spacing: 8
        Image {
            Layout.alignment: Qt.AlignVCenter
            source: Style.parameter("icon.bottomPanelLogo")
        }
        BasicLabel {
            Layout.alignment: Qt.AlignVCenter
            Style.class: "bottomPanelVersion"
            text: "v." + Session.versionInfo.version
        }
    }

    // Часы
    RowLayout {
        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter
        spacing: 4
        BasicLabel {
            id: date
            Style.class: "bottomPanelDate"
        }
        BasicLabel {
            Style.class: "bottomPanelDate"
            text: "/"
        }
        BasicLabel {
            id: clock
            Style.class: "bottomPanelClock"
        }
        Timer {
            interval: 500; running: true; repeat: true; triggeredOnStart: true
            onTriggered: {
                let currentDate = new Date()
                date.text = currentDate.toLocaleDateString(Qt.locale("en_US"), "dd.MM.yy")
                clock.text = currentDate.toLocaleTimeString(Qt.locale("en_US"), "hh:mm")
            }
        }
    }

    RowLayout {
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        anchors.rightMargin: 16
        spacing: 24
        BasicLabel {
            Style.class: "bottomPanelShift"
            Tr { code: "shiftNumber"; defaultMessage: "Смена %1"; args: [ Session.shiftNum ] }
        }
        BasicLabel {
            Style.class: "bottomPanelCash"
            Tr { code: "cashCode"; defaultMessage: "Касса %1"; args: [ Session.cashCode ] }
        }
    }
}
