import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../../components"

import Artix.Core
import Artix.Gui

/**
 * @brief Базовый боковой диалог выбора из списка
 * @param dataModel модель для списка
 * @param selectionModel модель выбора элемента списка (только для чтения)
 * @param delegate делегат списка
 * @param titleContent заголовок диалога (компонент для загрузки)
 * @param titleItem заголовок диалога (загруженный компонент)
 * @param cancelVisible отображение кнопки отмены
 */
SideView {
    property alias dataModel: listView.model
    readonly property ItemSelectionModel selectionModel: ItemSelectionModel { model: dataModel }
    property alias delegate: listView.delegate
    property alias titleContent: titleLoader.sourceComponent
    property alias cancelVisible: cancelButton.visible
    signal accept()
    signal reject()

    property DialogEventFilter eventFilter: DialogEventFilter { onCancel: reject() }

    padding: 0
    contentItem: ColumnLayout {
        spacing: 0
        Loader {
            Layout.leftMargin: 24
            Layout.rightMargin: 24
            Layout.topMargin: 16
            Layout.bottomMargin: 24
            Layout.fillWidth: true
            id: titleLoader
        }
        ListView {
            id: listView
            Layout.fillWidth: true
            Layout.fillHeight: true
            spacing: 1
            clip: true
        }
        RowLayout {
            spacing: 16
            Layout.rightMargin: 16
            Layout.topMargin: 24
            Layout.bottomMargin: 24
            Layout.alignment: Qt.AlignRight
            BasicButton {
                Style.class: "choiceListOk"
                Layout.preferredWidth: 200
                Layout.preferredHeight: 56
                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                horizontalAlignment: Qt.AlignHCenter
                verticalAlignment: Qt.AlignVCenter
                visible: selectionModel.hasSelection
                Tr { code: "selectButton"; defaultMessage: "Выбрать" }
                onClicked: accept()
            }
            BasicButton {
                id: cancelButton
                Style.class: "choiceListCancel"
                Layout.preferredWidth: 200
                Layout.preferredHeight: 56
                textLayout {
                    fillWidth: true
                    fillHeight: true
                }
                horizontalAlignment: Qt.AlignHCenter
                verticalAlignment: Qt.AlignVCenter
                Tr { code: "cancelButton"; defaultMessage: "Отмена" }
                onClicked: reject()
            }
        }
    }
}
